@@ -2,13 +2,13 @@ import requests
 
 
 class Client:
-    API_URL = "https://api.mailgun.net/v3"
+    DEFAULT_API_URL = "https://api.mailgun.net/v3"
 
     def __init__(self, mailgun):
         self.mailgun = mailgun
 
     def prepare_request(self, url: str, method="get", data=None, headers=None, params=None, **kwargs):
-        real_url = "%s/%s/%s" % (self.API_URL, self.mailgun.profile_settings["API"]["DOMAIN"], url)
+        real_url = "%s/%s/%s" % (self.get_api_url(), self.mailgun.profile_settings["API"]["DOMAIN"], url)
 
         auth = ("api", self.mailgun.profile_settings["API"]["API_KEY"])
 
@@ -21,3 +21,9 @@ class Client:
                                **kwargs)
 
         return req.prepare()
+
+    def get_api_url(self):
+        if "API_URL" in self.mailgun.profile_settings["API"].keys():
+            return self.mailgun.profile_settings["API"]["API_URL"]
+
+        return self.DEFAULT_API_URL
