@@ -10,21 +10,18 @@ class MailSentGroup:
     def get_mail_owners(self):
         raise NotImplementedError()
 
-    def send_new_mails(self, count=None, force=False):
+    def send_new_mails(self, count=None, force=False, fail_silently=False):
         mail_owners = self.get_mail_owners()
 
         if count is not None:
             mail_owners = mail_owners[:count]
 
-        if self.single_send_mode:
-            mails = []
+        mails = []
 
-            for mail_owner in mail_owners:
-                mail = self.template_mail_sender(mail_owner).send(force=force)
+        for mail_owner in mail_owners:
+            mail = self.template_mail_sender(mail_owner).send(force=force, fail_silently=fail_silently)
 
-                if mail:
-                    mails.append(mail[0])
-        else:
-            mails = self.template_mail_sender(mail_owners).send(force=force)
+            if mail:
+                mails.append(mail)
 
         return mails
